@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher;
 BEGIN {
-  $WWW::FetchStory::Fetcher::VERSION = '0.14';
+  $WWW::FetchStory::Fetcher::VERSION = '0.15';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 DESCRIPTION
 
@@ -630,6 +630,11 @@ sub parse_summary {
     {
 	$summary = $1;
     }
+    elsif ($content =~ m#<tr><(?:th|td)>Summary</(?:th|td)><td>(.*?)</td></tr>#s)
+    {
+	$summary = $1;
+	$summary =~ s/<br>/ /g;
+    }
     elsif ($content =~ /\bSummary:\s*"?(.*?)"?\s*<(?:br|p|\/p|div|\/div)/si)
     {
 	$summary = $1;
@@ -680,6 +685,11 @@ sub parse_characters {
     {
 	$characters = $1;
     }
+    elsif ($content =~ m#<tr><(?:th|td)>(?:Pairings|Characters)</(?:th|td)><td>(.*?)</td></tr>#s)
+    {
+	$characters = $1;
+	$characters =~ s/<br>/, /g;
+    }
     return $characters;
 } # parse_characters
 
@@ -724,6 +734,11 @@ sub parse_category {
     {
 	$category = $1;
     }
+    elsif ($content =~ m#<tr><(?:th|td)>Categories</(?:th|td)><td>(.*?)</td></tr>#s)
+    {
+	$category = $1;
+	$category =~ s/<br>/, /g;
+    }
     return $category;
 } # parse_category
 
